@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::ModuleBuildTiny::Fallback; # git description: v0.017-8-g3e0dabc
+package Dist::Zilla::Plugin::ModuleBuildTiny::Fallback; # git description: v0.018-5-g56ec6eb
 # ABSTRACT: Build a Build.PL that uses Module::Build::Tiny, falling back to Module::Build as needed
 # KEYWORDS: plugin installer Module::Build Build.PL toolchain legacy ancient backcompat
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.018';
+our $VERSION = '0.019';
 
 use Moose;
 use MooseX::Types;
@@ -104,6 +104,7 @@ around dump_config => sub
                 }
             } $self->plugins
         ],
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
     return $config;
@@ -245,7 +246,7 @@ FALLBACK2
 $mbt_content}
 else
 {
-    if (\$ENV{PERL_MB_FALLBACK_SILENCE_WARNING})
+    if (not \$ENV{PERL_MB_FALLBACK_SILENCE_WARNING})
     {
         warn <<'EOW';
 $message
@@ -284,12 +285,12 @@ __PACKAGE__->meta->make_immutable;
 #pod
 #pod When the L<Module::Build> fallback code is run, an added preamble is printed:
 #pod
-#pod =over 4
-#pod
 #pod =for stopwords cpanminus
 #pod
 #pod =for comment This section was inserted from the DATA section at build time
 #pod
+#pod =begin :verbatim
+#pod
 #pod *** WARNING WARNING WARNING WARNING WARNING WARNING WARNING WARNING ***
 #pod
 #pod If you're seeing this warning, your toolchain is really, really old* and you'll
@@ -321,7 +322,7 @@ __PACKAGE__->meta->make_immutable;
 #pod that until you fix your toolchain as described above.
 #pod
 #pod
-#pod =back
+#pod =end :verbatim
 #pod
 #pod =for stopwords ModuleBuild
 #pod
@@ -385,7 +386,7 @@ Dist::Zilla::Plugin::ModuleBuildTiny::Fallback - Build a Build.PL that uses Modu
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -407,43 +408,39 @@ the contents of F<META.yml> or F<META.json>.
 
 When the L<Module::Build> fallback code is run, an added preamble is printed:
 
-=over 4
-
 =for stopwords cpanminus
 
 =for comment This section was inserted from the DATA section at build time
 
-*** WARNING WARNING WARNING WARNING WARNING WARNING WARNING WARNING ***
+    *** WARNING WARNING WARNING WARNING WARNING WARNING WARNING WARNING ***
 
-If you're seeing this warning, your toolchain is really, really old* and you'll
-almost certainly have problems installing CPAN modules from this century. But
-never fear, dear user, for we have the technology to fix this!
+    If you're seeing this warning, your toolchain is really, really old* and you'll
+    almost certainly have problems installing CPAN modules from this century. But
+    never fear, dear user, for we have the technology to fix this!
 
-If you're using CPAN.pm to install things, then you can upgrade it using:
+    If you're using CPAN.pm to install things, then you can upgrade it using:
 
     cpan CPAN
 
-If you're using CPANPLUS to install things, then you can upgrade it using:
+    If you're using CPANPLUS to install things, then you can upgrade it using:
 
     cpanp CPANPLUS
 
-If you're using cpanminus, you shouldn't be seeing this message in the first
-place, so please file an issue on github.
+    If you're using cpanminus, you shouldn't be seeing this message in the first
+    place, so please file an issue on github.
 
-This public service announcement was brought to you by the Perl Toolchain
-Gang, the irc.perl.org #toolchain IRC channel, and the number 42.
+    This public service announcement was brought to you by the Perl Toolchain
+    Gang, the irc.perl.org #toolchain IRC channel, and the number 42.
 
-----
+    ----
 
-* Alternatively, you are running this file manually, in which case you need
-to learn to first fulfill all configure requires prerequisites listed in
-META.yml or META.json -- or use a cpan client to install this distribution.
+    * Alternatively, you are running this file manually, in which case you need
+    to learn to first fulfill all configure requires prerequisites listed in
+    META.yml or META.json -- or use a cpan client to install this distribution.
 
-You can also silence this warning for future installations by setting the
-PERL_MB_FALLBACK_SILENCE_WARNING environment variable, but please don't do
-that until you fix your toolchain as described above.
-
-=back
+    You can also silence this warning for future installations by setting the
+    PERL_MB_FALLBACK_SILENCE_WARNING environment variable, but please don't do
+    that until you fix your toolchain as described above.
 
 =for stopwords ModuleBuild
 
@@ -510,7 +507,7 @@ L<Dist::Zilla::Plugin::ModuleBuild>
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2014 by Karen Etheridge.
 
